package com.ruoyi.framework.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.framework.system.mapper.DoctorsMapper;
import com.ruoyi.framework.system.domain.Doctors;
import com.ruoyi.framework.system.service.IDoctorsService;

/**
 * 医生信息Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-11-13
 */
@Service
public class DoctorsServiceImpl implements IDoctorsService 
{
    @Autowired
    private DoctorsMapper doctorsMapper;

    /**
     * 查询医生信息
     * 
     * @param DoctorID 医生信息主键
     * @return 医生信息
     */
    @Override
    public Doctors selectDoctorsByDoctorID(Long DoctorID)
    {
        return doctorsMapper.selectDoctorsByDoctorID(DoctorID);
    }

    /**
     * 查询医生信息列表
     * 
     * @param doctors 医生信息
     * @return 医生信息
     */
    @Override
    public List<Doctors> selectDoctorsList(Doctors doctors)
    {
        return doctorsMapper.selectDoctorsList(doctors);
    }

    /**
     * 新增医生信息
     * 
     * @param doctors 医生信息
     * @return 结果
     */
    @Override
    public int insertDoctors(Doctors doctors)
    {
        return doctorsMapper.insertDoctors(doctors);
    }

    /**
     * 修改医生信息
     * 
     * @param doctors 医生信息
     * @return 结果
     */
    @Override
    public int updateDoctors(Doctors doctors)
    {
        return doctorsMapper.updateDoctors(doctors);
    }

    /**
     * 批量删除医生信息
     * 
     * @param DoctorIDs 需要删除的医生信息主键
     * @return 结果
     */
    @Override
    public int deleteDoctorsByDoctorIDs(Long[] DoctorIDs)
    {
        return doctorsMapper.deleteDoctorsByDoctorIDs(DoctorIDs);
    }

    /**
     * 删除医生信息信息
     * 
     * @param DoctorID 医生信息主键
     * @return 结果
     */
    @Override
    public int deleteDoctorsByDoctorID(Long DoctorID)
    {
        return doctorsMapper.deleteDoctorsByDoctorID(DoctorID);
    }
}
